Base classes (high level)
==========================

This module provides abstract base classes for high-level model implementations.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Base Model Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   BaseModel


Class Documentation
-------------------

.. autoclass:: BaseModel
   :members:
   :undoc-members:
   :show-inheritance:
